@@ -4,12 +4,12 @@
 <context>
     <name>AddAccountForm</name>
     <message>
-        <location filename="../../qutim-meta/protocols/irc/src/ui/addaccountform.ui" line="+14"/>
+        <location filename="../../qutim/protocols/irc/src/ui/addaccountform.ui" line="+14"/>
         <source>AddAccountForm</source>
         <translation>Добавяне на сметка</translation>
     </message>
     <message>
-        <location line="+6"/>
+        <location line="+30"/>
         <source>Network name:</source>
         <translation>Име на мрежа:</translation>
     </message>
@@ -53,11 +53,16 @@
         <source>Save password</source>
         <translation>Запис на паролата</translation>
     </message>
+    <message>
+        <location line="+7"/>
+        <source>Secure Connection (SSL)</source>
+        <translation>Защитена връзка (SSL)</translation>
+    </message>
 </context>
 <context>
     <name>Author</name>
     <message>
-        <location filename="../../qutim-meta/protocols/irc/src/ircplugin.cpp" line="+34"/>
+        <location filename="../../qutim/protocols/irc/src/ircplugin.cpp" line="+34"/>
         <source>Alexey Prokhin</source>
         <translation>Алексей Прохин</translation>
     </message>
@@ -65,16 +70,12 @@
 <context>
     <name>EditNickForm</name>
     <message>
-        <location filename="../../qutim-meta/protocols/irc/src/ui/editnickform.ui" line="+14"/>
+        <location filename="../../qutim/protocols/irc/src/ui/editnickform.ui" line="+14"/>
         <source>Form</source>
         <translation>Редактиране на псевдоним</translation>
     </message>
     <message>
-        <source>Nicks:</source>
-        <translation type="obsolete">Псевдоними:</translation>
-    </message>
-    <message>
-        <location line="+6"/>
+        <location line="+30"/>
         <source>Nick:</source>
         <translation>Псевдоним:</translation>
     </message>
@@ -387,11 +388,7 @@
 <context>
     <name>IRC</name>
     <message>
-        <source>Join channel...</source>
-        <translation type="obsolete">Присъединяване към канал...</translation>
-    </message>
-    <message>
-        <location filename="../../qutim-meta/protocols/irc/src/ircprotocol.cpp" line="+56"/>
+        <location filename="../../qutim/protocols/irc/src/ircprotocol.cpp" line="+88"/>
         <source>Show console...</source>
         <translation>Показване на конзолата...</translation>
     </message>
@@ -401,22 +398,10 @@
         <translation>Търсене на канал...</translation>
     </message>
     <message>
-        <source>Join channel</source>
-        <translation type="obsolete">Присъединяване към канал</translation>
-    </message>
-    <message>
-        <location filename="../../qutim-meta/protocols/irc/src/ircgroupchatmanager.cpp" line="+64"/>
+        <location filename="../../qutim/protocols/irc/src/ircgroupchatmanager.cpp" line="+63"/>
         <source>Channel</source>
         <translation>Канал</translation>
     </message>
-    <message>
-        <source>Autojoin</source>
-        <translation type="obsolete">Автоматично присъединяване</translation>
-    </message>
-    <message>
-        <source>Yes</source>
-        <translation type="obsolete">Да</translation>
-    </message>
     <message>
         <location line="-6"/>
         <source>Name</source>
@@ -436,59 +421,7 @@
 <context>
     <name>IrcChannel</name>
     <message>
-        <source>You are now known as %1</source>
-        <translation type="obsolete">В момента се подвизавате като %1</translation>
-    </message>
-    <message>
-        <source>%1 are now known as %2</source>
-        <translation type="obsolete">%1 вече се подвизава като %2</translation>
-    </message>
-    <message>
-        <source>%1 (%2) has joined the channel</source>
-        <translation type="obsolete">%1 (%2) се присъедини към канала</translation>
-    </message>
-    <message>
-        <source>You left this channel</source>
-        <translation type="obsolete">Напуснахте канала</translation>
-    </message>
-    <message>
-        <source>You left this channel (%1)</source>
-        <translation type="obsolete">Напуснахте канала (%1)</translation>
-    </message>
-    <message>
-        <source>%1 has left this channel (%2)</source>
-        <translation type="obsolete">%1 напусна канала (%2)</translation>
-    </message>
-    <message>
-        <source>%1 has left this channel</source>
-        <translation type="obsolete">%1 напусна канала</translation>
-    </message>
-    <message>
-        <source>%1 has kicked you from the channel (%2)</source>
-        <translation type="obsolete">%1 ви изрита от канала (%2)</translation>
-    </message>
-    <message>
-        <source>%1 has kicked you from the channel</source>
-        <translation type="obsolete">%1 ви изрита от канала</translation>
-    </message>
-    <message>
-        <source>%1 has kicked %2 (%3)</source>
-        <translation type="obsolete">%1 изрита %2 (%3)</translation>
-    </message>
-    <message>
-        <source>%1 has kicked %2</source>
-        <translation type="obsolete">%1 изрита %2</translation>
-    </message>
-    <message>
-        <source>The channel topic is &quot;%1&quot;</source>
-        <translation type="obsolete">Заглавието на канала е &quot;%1&quot;</translation>
-    </message>
-    <message>
-        <source>The topic was set by %1 on %2.</source>
-        <translation type="obsolete">Заглавието на канала е зададено от %1 на %2.</translation>
-    </message>
-    <message>
-        <location filename="../../qutim-meta/protocols/irc/src/ircchannel.cpp" line="+341"/>
+        <location filename="../../qutim/protocols/irc/src/ircchannel.cpp" line="+374"/>
         <source>%1 gives channel operator privileges to %2.</source>
         <translation>%1 даде операторски права в канала на %2.</translation>
     </message>
@@ -521,27 +454,15 @@
 <context>
     <name>IrcChannelListForm</name>
     <message>
-        <location filename="../../qutim-meta/protocols/irc/src/ui/ircchannellist.ui" line="+14"/>
+        <location filename="../../qutim/protocols/irc/src/ui/ircchannellist.ui" line="+14"/>
         <source>Form</source>
         <translation>Канали</translation>
     </message>
-    <message>
-        <source>Channel</source>
-        <translation type="obsolete">Канал</translation>
-    </message>
-    <message>
-        <source>Users</source>
-        <translation type="obsolete">Потребители</translation>
-    </message>
-    <message>
-        <source>Topic</source>
-        <translation type="obsolete">Тема</translation>
-    </message>
 </context>
 <context>
     <name>IrcConsoleForm</name>
     <message>
-        <location filename="../../qutim-meta/protocols/irc/src/ui/console.ui" line="+14"/>
+        <location filename="../../qutim/protocols/irc/src/ui/console.ui" line="+14"/>
         <source>IRC Server Console</source>
         <translation>Конзола на IRC сървъра</translation>
     </message>
@@ -549,7 +470,7 @@
 <context>
     <name>Plugin</name>
     <message>
-        <location filename="../../qutim-meta/protocols/irc/src/ircplugin.cpp" line="-3"/>
+        <location filename="../../qutim/protocols/irc/src/ircplugin.cpp" line="-3"/>
         <location line="+6"/>
         <source>IRC</source>
         <translation>IRC</translation>
@@ -575,32 +496,37 @@
         <source>Proxy support for IRC protocol</source>
         <translation>Поддръжка на прокси за IRC протокола</translation>
     </message>
-    <message>
-        <source>ICQ account creator</source>
-        <translation type="obsolete">Създаване на IRC сметка</translation>
-    </message>
     <message>
         <location line="-4"/>
         <source>Account creator for IRC protocol</source>
         <translation>Създаване на сметка за IRC протокола</translation>
     </message>
-    <message>
-        <source>Channel</source>
-        <translation type="obsolete">Канал</translation>
-    </message>
 </context>
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../../qutim-meta/protocols/irc/src/irccommandalias.cpp" line="+71"/>
+        <location filename="../../qutim/protocols/irc/src/irccommandalias.cpp" line="+111"/>
         <source>Not enough parameters for command %1</source>
         <translation>Липсват достатъчно параметри за командата %1</translation>
     </message>
 </context>
+<context>
+    <name>Settings</name>
+    <message>
+        <location filename="../../qutim/protocols/irc/src/ircprotocol.cpp" line="-31"/>
+        <source>User information</source>
+        <translation>Информация за потребителя</translation>
+    </message>
+    <message>
+        <location line="+5"/>
+        <source>Servers</source>
+        <translation>Сървъри</translation>
+    </message>
+</context>
 <context>
     <name>Task</name>
     <message>
-        <location filename="../../qutim-meta/protocols/irc/src/ircplugin.cpp" line="-7"/>
+        <location filename="../../qutim/protocols/irc/src/ircplugin.cpp" line="-7"/>
         <source>Author</source>
         <translation>Автор</translation>
     </message>
@@ -608,7 +534,7 @@
 <context>
     <name>qutim_sdk_0_3::irc::ChannelsModel</name>
     <message>
-        <location filename="../../qutim-meta/protocols/irc/src/ui/ircchannellist.cpp" line="+81"/>
+        <location filename="../../qutim/protocols/irc/src/ui/ircchannellist.cpp" line="+81"/>
         <source>Channel</source>
         <translation>Канал</translation>
     </message>
@@ -626,7 +552,7 @@
 <context>
     <name>qutim_sdk_0_3::irc::IrcAccount</name>
     <message>
-        <location filename="../../qutim-meta/protocols/irc/src/ircaccount.cpp" line="+80"/>
+        <location filename="../../qutim/protocols/irc/src/ircaccount.cpp" line="+73"/>
         <source>Away</source>
         <translation>Отсъствам</translation>
     </message>
@@ -634,7 +560,7 @@
 <context>
     <name>qutim_sdk_0_3::irc::IrcChannel</name>
     <message>
-        <location filename="../../qutim-meta/protocols/irc/src/ircchannel.cpp" line="-208"/>
+        <location filename="../../qutim/protocols/irc/src/ircchannel.cpp" line="-208"/>
         <source>You are now known as %1</source>
         <translation>В момента се подвизавате като %1</translation>
     </message>
@@ -702,7 +628,7 @@
 <context>
     <name>qutim_sdk_0_3::irc::IrcChannelListForm</name>
     <message>
-        <location filename="../../qutim-meta/protocols/irc/src/ui/ircchannellist.cpp" line="+93"/>
+        <location filename="../../qutim/protocols/irc/src/ui/ircchannellist.cpp" line="+93"/>
         <source>Fetching channels list...</source>
         <translation>Изтегляне на списъка с канали...</translation>
     </message>
@@ -717,10 +643,230 @@
         <translation>Изтегляне на списъка с канали... (%1)</translation>
     </message>
 </context>
+<context>
+    <name>qutim_sdk_0_3::irc::IrcCommandAlias</name>
+    <message>
+        <location filename="../../qutim/protocols/irc/src/irccommandalias.cpp" line="+89"/>
+        <source>Kick / Ban</source>
+        <translation>Изритване/Забрана</translation>
+    </message>
+    <message>
+        <location line="+3"/>
+        <source>Kick</source>
+        <translation>Изритване</translation>
+    </message>
+    <message>
+        <location line="+5"/>
+        <source>Kickban</source>
+        <translation>Изритване със забрана</translation>
+    </message>
+    <message>
+        <location line="+3"/>
+        <source>Ban</source>
+        <translation>Забрана</translation>
+    </message>
+    <message>
+        <location line="+4"/>
+        <source>Ban *!*@*.host</source>
+        <translation>Забрана *!*@*.host</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>Ban *!*@domain</source>
+        <translation>Забрана *!*@domain</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>Ban *!user@*.host</source>
+        <translation>Забрана *!user@*.host</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>Ban *!user@domain</source>
+        <translation>Забрана *!user@domain</translation>
+    </message>
+    <message>
+        <location line="+3"/>
+        <source>Kickban *!*@*.host</source>
+        <translation>Изритване със забрана *!*@*.host</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>Kickban *!*@domain</source>
+        <translation>Изритване със забрана *!*@domain</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>Kickban *!user@*.host</source>
+        <translation>Изритване със забрана *!user@*.host</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>Kickban *!user@domain</source>
+        <translation>Изритване със забрана *!user@domain</translation>
+    </message>
+    <message>
+        <location line="+4"/>
+        <source>Ping</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>Request client information</source>
+        <translation>Заявка за информация за клиента</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>Request version</source>
+        <translation>Заявка за версия</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>Request time</source>
+        <translation>Заявка за време</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>Avatar</source>
+        <translation>Аватар</translation>
+    </message>
+    <message>
+        <location line="+3"/>
+        <source>Modes</source>
+        <translation>Режими</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>Give Op</source>
+        <translation>Предоставяне на операторски права</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>Take Op</source>
+        <translation>Отнемане на операторските права</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>Give HalfOp</source>
+        <translation>Предоставяне на полуоператорски права</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>Take HalfOp</source>
+        <translation>Отнемане на полуоператорските права</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>Give voice</source>
+        <translation>Предоставяне на глас</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>Take voice</source>
+        <translation>Отнемане на глас</translation>
+    </message>
+    <message>
+        <location line="+4"/>
+        <source>Send WHOIS request</source>
+        <translation>Изпращане WHOIS заявка</translation>
+    </message>
+</context>
 <context>
     <name>qutim_sdk_0_3::irc::IrcConnection</name>
     <message>
-        <location filename="../../qutim-meta/protocols/irc/src/ircconnection.cpp" line="+176"/>
+        <source>Kick / Ban</source>
+        <translation type="obsolete">Изритване/Забрана</translation>
+    </message>
+    <message>
+        <source>Kick</source>
+        <translation type="obsolete">Изритване</translation>
+    </message>
+    <message>
+        <source>Kickban</source>
+        <translation type="obsolete">Изритване със забрана</translation>
+    </message>
+    <message>
+        <source>Ban</source>
+        <translation type="obsolete">Забрана</translation>
+    </message>
+    <message>
+        <source>Ban *!*@*.host</source>
+        <translation type="obsolete">Забрана *!*@*.host</translation>
+    </message>
+    <message>
+        <source>Ban *!*@domain</source>
+        <translation type="obsolete">Забрана *!*@domain</translation>
+    </message>
+    <message>
+        <source>Ban *!user@*.host</source>
+        <translation type="obsolete">Забрана *!user@*.host</translation>
+    </message>
+    <message>
+        <source>Ban *!user@domain</source>
+        <translation type="obsolete">Забрана *!user@domain</translation>
+    </message>
+    <message>
+        <source>Kickban *!*@*.host</source>
+        <translation type="obsolete">Изритване със забрана *!*@*.host</translation>
+    </message>
+    <message>
+        <source>Kickban *!*@domain</source>
+        <translation type="obsolete">Изритване със забрана *!*@domain</translation>
+    </message>
+    <message>
+        <source>Kickban *!user@*.host</source>
+        <translation type="obsolete">Изритване със забрана *!user@*.host</translation>
+    </message>
+    <message>
+        <source>Kickban *!user@domain</source>
+        <translation type="obsolete">Изритване със забрана *!user@domain</translation>
+    </message>
+    <message>
+        <source>Request client information</source>
+        <translation type="obsolete">Заявка за информация за клиента</translation>
+    </message>
+    <message>
+        <source>Request version</source>
+        <translation type="obsolete">Заявка за версия</translation>
+    </message>
+    <message>
+        <source>Request time</source>
+        <translation type="obsolete">Заявка за време</translation>
+    </message>
+    <message>
+        <source>Request avatar</source>
+        <translation type="obsolete">Заявка за аватар</translation>
+    </message>
+    <message>
+        <source>Modes</source>
+        <translation type="obsolete">Режими</translation>
+    </message>
+    <message>
+        <source>Give Op</source>
+        <translation type="obsolete">Предоставяне на операторски права</translation>
+    </message>
+    <message>
+        <source>Take Op</source>
+        <translation type="obsolete">Отнемане на операторските права</translation>
+    </message>
+    <message>
+        <source>Give HalfOp</source>
+        <translation type="obsolete">Предоставяне на полуоператорски права</translation>
+    </message>
+    <message>
+        <source>Take HalfOp</source>
+        <translation type="obsolete">Отнемане на полуоператорските права</translation>
+    </message>
+    <message>
+        <source>Give voice</source>
+        <translation type="obsolete">Предоставяне на глас</translation>
+    </message>
+    <message>
+        <source>Take voice</source>
+        <translation type="obsolete">Отнемане на глас</translation>
+    </message>
+    <message>
+        <location filename="../../qutim/protocols/irc/src/ircconnection.cpp" line="+147"/>
         <source>Server %1 (Version %2), User modes: %3, Channel modes: %4</source>
         <translation>Сървър %1 (версия %2) Потребителски режими: %3, Режими на каналите: %4</translation>
     </message>
@@ -735,7 +881,11 @@
         <translation>Край на съобщението за деня</translation>
     </message>
     <message>
-        <location line="+7"/>
+        <location line="+8"/>
+        <source>Start of /LIST</source>
+        <translation>Начало на /LIST</translation>
+    </message>
+    <message>
         <location line="+18"/>
         <source>End of /LIST</source>
         <translation>Край на /LIST</translation>
@@ -752,8 +902,129 @@ Please wait a while and try again.</source>
         <translation>Временно сървърът е натоварен.
 Моля, изчакайте малко и опитайте отново.</translation>
     </message>
+    <message>
+        <location line="+11"/>
+        <source>%1 set away message &quot;%2&quot;</source>
+        <translation>%1 зададе съобщение при отсъствие: &quot;%2&quot;</translation>
+    </message>
+    <message>
+        <location line="+305"/>
+        <source>SSL error: %1</source>
+        <translation>SSL грешка: %1</translation>
+    </message>
+    <message>
+        <location line="+6"/>
+        <source>SSL handshake completed</source>
+        <translation>SSL handshake приключи</translation>
+    </message>
+    <message>
+        <source>%1 set away message %2</source>
+        <translation type="obsolete">%1 зададе съобщение при отсъствие: %2</translation>
+    </message>
+    <message>
+        <location line="-307"/>
+        <source>%1 removed away message</source>
+        <translation>%1 премахна съобщението при отсъствие</translation>
+    </message>
+    <message>
+        <location line="+5"/>
+        <source>You are no longer marked as being away</source>
+        <translation>Вече не сте отбелязан(а) като отсъстващ(а)</translation>
+    </message>
+    <message>
+        <location line="+2"/>
+        <source>You have been marked as being away</source>
+        <translation>Отбелязан(а) сте като отсъстващ(а)</translation>
+    </message>
+    <message>
+        <source>%1 is %2@%3 (%4)</source>
+        <translation type="obsolete">%1 е %2@%3 (%4)</translation>
+    </message>
+    <message>
+        <source>%1 is online via %2 (%3)</source>
+        <translation type="obsolete">%1 е на линия през %2 (%3)</translation>
+    </message>
+    <message>
+        <source>%1 is an IRC operator</source>
+        <translation type="obsolete">%1 е IRC оператор</translation>
+    </message>
+    <message>
+        <source>%1 has been idle since</source>
+        <translation type="obsolete">%1 бездейства от</translation>
+    </message>
+    <message>
+        <source>%1 has been online since</source>
+        <translation type="obsolete">%1 е бил(а) на линия от</translation>
+    </message>
+    <message>
+        <source>%1 is a user on channels: </source>
+        <translation type="obsolete">%1 е потребител в следните канали: </translation>
+    </message>
+    <message>
+        <source>%1 is logged in as %2</source>
+        <translation type="obsolete">%1 се е вписал като %2</translation>
+    </message>
+    <message>
+        <source>%1 is using a secure connection</source>
+        <translation type="obsolete">%1 използва защитена връзка</translation>
+    </message>
     <message numerus="yes">
-        <location line="+44"/>
+        <source>Received CTCP-PING reply from %1: %2 seconds</source>
+        <translation type="obsolete">
+            <numerusform>Получен CTCP-PING отговор от %1: %2 секунда</numerusform>
+            <numerusform>Получен CTCP-PING отговор от %1: %2 секунди</numerusform>
+        </translation>
+    </message>
+    <message>
+        <source>Received CTCP-%1 reply from %2: %3</source>
+        <translation type="obsolete">Получен CTCP-%1 отговор от %2: %3</translation>
+    </message>
+    <message>
+        <location line="+99"/>
+        <source>Add at least one server before connecting</source>
+        <translation>Добавeте поне един сървър преди да се свържете</translation>
+    </message>
+    <message>
+        <location line="+2"/>
+        <source>Set at least one nick before connecting</source>
+        <translation>Задайте поне един псевдоним преди да се свържете</translation>
+    </message>
+    <message>
+        <location line="+2"/>
+        <source>Cannot connect to %1 network</source>
+        <translation>Невъзможно е свързването към мрежата %1</translation>
+    </message>
+    <message>
+        <location line="+177"/>
+        <source>Network error: %1</source>
+        <translation>Мрежова грешка: %1</translation>
+    </message>
+</context>
+<context>
+    <name>qutim_sdk_0_3::irc::IrcJoinLeftActionGenerator</name>
+    <message>
+        <location filename="../../qutim/protocols/irc/src/ircchannel.cpp" line="-310"/>
+        <source>Leave the channel</source>
+        <translation>Напускане на канала</translation>
+    </message>
+    <message>
+        <location line="+2"/>
+        <source>Join the channel</source>
+        <translation>Присъединяване към канала</translation>
+    </message>
+</context>
+<context>
+    <name>qutim_sdk_0_3::irc::IrcProtocol</name>
+    <message>
+        <location filename="../../qutim/protocols/irc/src/ircprotocol.cpp" line="+2"/>
+        <source>Auto-join</source>
+        <translation>Автоматично присъединяване</translation>
+    </message>
+</context>
+<context>
+    <name>qutim_sdk_0_3::irc::IrcStandartCtpcHandler</name>
+    <message numerus="yes">
+        <location filename="../../qutim/protocols/irc/src/ircstandartctpchandler.cpp" line="+69"/>
         <source>Received CTCP-PING reply from %1: %2 seconds</source>
         <translation>
             <numerusform>Получен CTCP-PING отговор от %1: %2 секунда</numerusform>
@@ -765,9 +1036,48 @@ Please wait a while and try again.</source>
         <source>Received CTCP-%1 reply from %2: %3</source>
         <translation>Получен CTCP-%1 отговор от %2: %3</translation>
     </message>
+</context>
+<context>
+    <name>qutim_sdk_0_3::irc::IrcWhoisRepliesHandler</name>
     <message>
-        <source>Not enough parameters for command %1</source>
-        <translation type="obsolete">Липсват достатъчно параметри за командата %1</translation>
+        <location filename="../../qutim/protocols/irc/src/ircwhoisreplieshandler.cpp" line="+53"/>
+        <source>%1 is %2@%3 (%4)</source>
+        <translation>%1 е %2@%3 (%4)</translation>
+    </message>
+    <message>
+        <location line="+13"/>
+        <source>%1 is online via %2 (%3)</source>
+        <translation>%1 е на линия през %2 (%3)</translation>
+    </message>
+    <message>
+        <location line="+7"/>
+        <source>%1 is an IRC operator</source>
+        <translation>%1 е IRC оператор</translation>
+    </message>
+    <message>
+        <location line="+10"/>
+        <source>%1 has been idle since</source>
+        <translation>%1 бездейства от</translation>
+    </message>
+    <message>
+        <location line="+6"/>
+        <source>%1 has been online since</source>
+        <translation>%1 е бил(а) на линия от</translation>
+    </message>
+    <message>
+        <location line="+8"/>
+        <source>%1 is a user on channels: </source>
+        <translation>%1 е потребител в следните канали: </translation>
+    </message>
+    <message>
+        <location line="+7"/>
+        <source>%1 is logged in as %2</source>
+        <translation>%1 се е вписал като %2</translation>
+    </message>
+    <message>
+        <location line="+5"/>
+        <source>%1 is using a secure connection</source>
+        <translation>%1 използва защитена връзка</translation>
     </message>
 </context>
 </TS>
