@@ -4,15 +4,19 @@
 <context>
     <name>Author</name>
     <message>
-        <location filename="../../qutim-meta/plugins/unreadmessageskeeper/src/unreadmessageskeeper.cpp" line="+31"/>
-        <source>Aleksey Sidorov</source>
+        <location filename="../../qutim/plugins/unreadmessageskeeper/src/unreadmessageskeeper.cpp" line="+32"/>
+        <source>Sidorov Aleksey</source>
         <translation>Алексей Сидоров</translation>
     </message>
+    <message>
+        <source>Aleksey Sidorov</source>
+        <translation type="obsolete">Алексей Сидоров</translation>
+    </message>
 </context>
 <context>
     <name>Plugin</name>
     <message>
-        <location line="-3"/>
+        <location line="-4"/>
         <source>UnreadMessagesKeeper</source>
         <translation>Съхраняване на непрочетени съобщения</translation>
     </message>
@@ -25,7 +29,7 @@
 <context>
     <name>Task</name>
     <message>
-        <location line="+3"/>
+        <location line="+4"/>
         <source>Developer</source>
         <translation>Разработчик</translation>
     </message>
